/*
 * Copyright (C) 2021  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "include/libhermes/email/send.hh"

#include "include/libhermes/connection.hh"
#include "include/libhermes/exception.hh"
#include "include/libhermes/service.hh"
#include "include/libhermes/strong_type.hh"

#include "src/email/proto_unwrap.hh"
#include "src/email/proto_wrap.hh"
#include "src/email/send_email_reply.hh"
#include "src/email/send_email_request.hh"
#include "src/get_stub.hh"

#include "fred_api/messenger/service_email_grpc.pb.h"

#include <grpcpp/client_context.h>

#include <iostream>
#include <stdexcept>

namespace LibHermes {
namespace Email {

namespace Api = Fred::Messenger::Api;

Email make_minimal_email(
        const Email::Recipient& _recipient,
        const Email::SubjectTemplate& _subject_template,
        const Email::BodyTemplate& _body_template)
{
    return Email{
        {},
        _recipient,
        {},
        Email::Type::nullopt,
        _subject_template,
        _body_template,
        Email::BodyTemplateHtml::nullopt,
        {},
        {},
        Email::SubjectTemplateUuid::nullopt,
        Email::BodyTemplateUuid::nullopt,
        Email::BodyTemplateHtmlUuid::nullopt
    };
}

EmailUid send(
        const Connection<Service::EmailMessenger>& _connection,
        const Email& _email,
        const Archive& _archive,
        const std::vector<Reference>& _references)
{
    grpc::ClientContext context;
    Api::Email::SendEmailRequest send_email_request;
    Api::Email::SendEmailReply send_email_reply;

    proto_wrap(SendEmailRequest{_email, _archive, _references}, &send_email_request);

    const auto status = get_stub(_connection).send(&context, send_email_request, &send_email_reply);

    if (!status.ok())
    {
        throw SendFailed(status.error_code(), status.error_message());
    }

    return proto_unwrap(send_email_reply).uid;
}

} // namespace LibHermes::Email
} // namespace LibHermes
