/*
 * Copyright (C) 2021  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "src/impl/notify_object_state_changes.hh"

#include <boost/test/unit_test.hpp>

BOOST_AUTO_TEST_SUITE(TestObjectStateChanges)

BOOST_AUTO_TEST_CASE(enums)
{
    using namespace Fred::Notify::ObjectStateChanges::Impl;

    BOOST_CHECK_EQUAL(to_string(Notification::ObjectType::contact), "contact");
    BOOST_CHECK_EQUAL(to_string(Notification::ObjectType::nsset), "nsset");
    BOOST_CHECK_EQUAL(to_string(Notification::ObjectType::domain), "domain");
    BOOST_CHECK_EQUAL(to_string(Notification::ObjectType::keyset), "keyset");

    BOOST_CHECK_EQUAL(to_string(Notification::Flag::expirationWarning), "expirationWarning");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::unguarded), "unguarded");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::validationWarning1), "validationWarning1");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::validationWarning2), "validationWarning2");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::nssetMissing), "nssetMissing");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::deleteWarning), "deleteWarning");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::outzoneUnguarded), "outzoneUnguarded");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::deleteCandidate), "deleteCandidate");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::contactPassedManualVerification), "contactPassedManualVerification");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::contactInManualVerification), "contactInManualVerification");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::contactFailedManualVerification), "contactFailedManualVerification");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::expired), "expired");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::mojeidContact), "mojeidContact");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::outzone), "outzone");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::identifiedContact), "identifiedContact");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::conditionallyIdentifiedContact), "conditionallyIdentifiedContact");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::validatedContact), "validatedContact");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverOutzoneManual), "serverOutzoneManual");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverInzoneManual), "serverInzoneManual");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::notValidated), "notValidated");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::linked), "linked");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverUpdateProhibited), "serverUpdateProhibited");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverTransferProhibited), "serverTransferProhibited");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverRegistrantChangeProhibited), "serverRegistrantChangeProhibited");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverRenewProhibited), "serverRenewProhibited");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverDeleteProhibited), "serverDeleteProhibited");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::serverBlocked), "serverBlocked");
    BOOST_CHECK_EQUAL(to_string(Notification::Flag::outzoneUnguardedWarning), "outzoneUnguardedWarning");

    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::sendauthinfo_pif), "sendauthinfo_pif");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::sendauthinfo_epp), "sendauthinfo_epp");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_create), "notification_create");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_update), "notification_update");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::annual_contact_reminder), "annual_contact_reminder");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::mojeid_verified_contact_transfer), "mojeid_verified_contact_transfer");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::mojeid_email_change), "mojeid_email_change");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::conditional_contact_identification), "conditional_contact_identification");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::contact_identification), "contact_identification");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_notify), "expiration_notify");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_dns_owner), "expiration_dns_owner");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_register_owner), "expiration_register_owner");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_dns_tech), "expiration_dns_tech");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_register_tech), "expiration_register_tech");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_validation_before), "expiration_validation_before");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_validation), "expiration_validation");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_transfer), "notification_transfer");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_renew), "notification_renew");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_unused), "notification_unused");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::notification_delete), "notification_delete");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::techcheck), "techcheck");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::invoice_deposit), "invoice_deposit");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::invoice_audit), "invoice_audit");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::invoice_noaudit), "invoice_noaudit");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::request_block), "request_block");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::merge_contacts_auto), "merge_contacts_auto");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::contact_check_notice), "contact_check_notice");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::contact_check_warning), "contact_check_warning");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::mojeid_identification), "mojeid_identification");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::mojeid_validation), "mojeid_validation");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::expiration_dns_warning_owner), "expiration_dns_warning_owner");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::akm_candidate_state_ok), "akm_candidate_state_ok");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::akm_candidate_state_ko), "akm_candidate_state_ko");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::akm_keyset_update), "akm_keyset_update");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::record_statement), "record_statement");
    BOOST_CHECK_EQUAL(to_string(Notification::MailTemplate::sendpersonalinfo_pif), "sendpersonalinfo_pif");

    BOOST_CHECK_EQUAL(to_string(Notification::Recipient::admin), "admin");
    BOOST_CHECK_EQUAL(to_string(Notification::Recipient::tech), "tech");
    BOOST_CHECK_EQUAL(to_string(Notification::Recipient::generic), "generic");
    BOOST_CHECK_EQUAL(to_string(Notification::Recipient::additional), "additional");
};

BOOST_AUTO_TEST_SUITE_END() // TestObjectStateChanges
